==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Tags",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag…" : "Tag wählen",
    "Tagged files" : "Getaggte Dateien",
    "Select tags to filter by" : "Wählen Sie Tags nach denen gefiltert werden soll",
    "No tags found" : "Keine Tags gefunden",
    "Please select tags to filter by" : "Bitte wählen Sie Tags nach denen gefiltert werden sollen",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Sie haben den System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Sie haben den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Sie haben den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Sie haben den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hast den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sie haben den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "You added system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Sie haben den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "You removed system tag %2$s from %1$s" : "Sie haben den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Sie haben den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei sind geändert worden",
    "Collaborative tags" : "Gemeinsame Tags",
    "Name" : "Name",
    "Delete" : "Löschen",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "You assigned system tag %3$s" : "Sie haben den System-Tag %3$s zugeordnet",
    "%1$s assigned system tag %3$s" : "%1$s hat den System-Tag %3$s zugeordnet",
    "You unassigned system tag %3$s" : "Sie haben den System-Tag %3$s entfernt",
    "%1$s unassigned system tag %3$s" : "%1$s hat den System-Tag %3$s entfernt",
    "You created system tag %2$s" : "Sie haben den System-Tag %2$s erstellt",
    "You deleted system tag %2$s" : "Sie haben den System-Tag %2$s gelöscht",
    "You updated system tag %3$s to %2$s" : "Sie haben den System-Tag %3$s zu %2$s aktualisiert",
    "You assigned system tag %3$s to %2$s" : "Sie haben den System-Tag %3$s an %2$s zugeordnet",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s hat den System-Tag %3$s an %2$s zugeordnet",
    "You unassigned system tag %3$s from %2$s" : "Sie haben den System-Tag %3$s von %2$s  entfernt",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s hat den System-Tag %3$s von %2$s entfernt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Tags",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag…" : "Tag wählen…",
    "Tagged files" : "Mit Tags versehene Dateien",
    "Select tags to filter by" : "Wählen Sie Tags nach denen gefiltert werden soll",
    "No tags found" : "Keine Tags gefunden",
    "Please select tags to filter by" : "Bitte wählen Sie Tags nach denen gefiltert werden sollen",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Sie haben den System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Sie haben den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Sie haben den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Sie haben den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat den System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sie haben den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "You added system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Sie haben den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat den System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "You removed system tag %2$s from %1$s" : "Sie haben den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Sie haben den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat den System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tag</strong> für eine Datei wurden geändert",
    "Collaborative tags" : "Kollaborative Tags",
    "Collaborative tagging functionality which shares tags among users." : "Kollaborative Tags-Funktionalität, welche Tags unter den Benutzern teilt.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Kollaborative Tags-Funktionalität, welche Tags unter den Benutzern teilt. Sehr gut für Gruppen.\n\t(Wenn Sie ein Anbieter mit einer Mehrkundeninstallation sind, so ist angeraten diese App zu deaktiveren, da die Tags mit allen Kunden geteilt werden.)",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Gemeinschaftliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nichtsichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
    "Select tag …" : "Tag wählen …",
    "Create a new tag" : "Neues Schlagwort erstellen",
    "Name" : "Name",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Delete" : "Löschen",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "Create and edit collaborative tags. These tags affect all users." : "Erstellen und bearbeiten Sie kollaborative Tags. Diese Tags betreffen alle Benutzer."
},
"nplurals=2; plural=(n != 1);");
